API Reference
=============

This section provides detailed API documentation for ConfigBuddy.

Core Classes
------------

Config
~~~~~~

.. automodule:: configbuddy.core.config
   :members:
   :undoc-members:
   :show-inheritance:

ConfigDiff
~~~~~~~~~~

.. autoclass:: configbuddy.core.config.ConfigDiff
   :members:
   :undoc-members:
   :show-inheritance:

ConfigMerger
~~~~~~~~~~~~

.. automodule:: configbuddy.core.merger
   :members:
   :undoc-members:
   :show-inheritance:

ConfigValidator
~~~~~~~~~~~~~~~

.. automodule:: configbuddy.core.validator
   :members:
   :undoc-members:
   :show-inheritance:

Visualizer
~~~~~~~~~~

.. automodule:: configbuddy.core.visualizer
   :members:
   :undoc-members:
   :show-inheritance:

Types
-----

.. automodule:: configbuddy.core.types
   :members:
   :undoc-members:
   :show-inheritance:

CLI
---

.. automodule:: configbuddy.cli.cli
   :members:
   :undoc-members:
   :show-inheritance: 